@@ -1,10 +1,10 @@
 """ntier API."""
-from ntier.api_transaction_base import APITransactionBase
 from ntier.data import TransactionData, TransactionInput, TransactionState
 from ntier.deserialize import Deserialize
 from ntier.messages import Messages
 from ntier.paging import Paging
 from ntier.policy_result import PolicyResult
+from ntier.serialize import Serialize
 from ntier.transaction_base import TransactionBase
 from ntier.transaction_code import TransactionCode
 from ntier.transaction_result import TransactionResult
