@@ -2,6 +2,8 @@
 from dataclasses import dataclass
 from typing import Any, Mapping, MutableMapping
 
+from .paging import Paging
+
 TransactionInput = Mapping[str, Any]
 TransactionState = MutableMapping[str, Any]
 
@@ -12,3 +14,4 @@ class TransactionData:
 
     input: TransactionInput
     state: TransactionState
+    paging: Paging
