@@ -37,3 +37,15 @@ class Messages:
 
     def has_general_message(self) -> bool:
         return self.has_message_for(_GENERAL_SUBJECT)
+
+    def merge(self, message_data: MessageData) -> "Messages":
+        for (key, values) in message_data.items():
+            for value in values:
+                self.add_message(key, value)
+        return self
+
+    def union(self, other: "Messages") -> "Messages":
+        messages = Messages()
+        messages.merge(self.messages)
+        messages.merge(other.messages)
+        return messages
