@@ -1,12 +1,10 @@
 """Contains the ValidationResult data structure."""
-from typing import Generic, Optional, TypeVar
+from typing import Optional
 
 from .messages import MessageData, Messages
 
-T = TypeVar("T")
 
-
-class ValidationResult(Generic[T]):
+class ValidationResult:
     """Contains information about whether a validation passes or fails."""
 
     def __init__(self, messages: Optional[Messages] = None) -> None:
@@ -37,9 +35,18 @@ class ValidationResult(Generic[T]):
         self._messages.add_general_message(message)
         return self
 
+    def has_failed_for(self, subject: str) -> bool:
+        if not self._messages:
+            return False
+        return self._messages.has_message_for(subject)
+
+    def union(self, other: "ValidationResult") -> "ValidationResult":
+        messages = Messages().merge(self.messages).merge(other.messages)
+        return ValidationResult(messages)
+
     @classmethod
     def success(cls) -> "ValidationResult":
-        return ValidationResult(None)
+        return ValidationResult()
 
     @classmethod
     def failed(cls, messages: Messages) -> "ValidationResult":
@@ -47,4 +54,4 @@ class ValidationResult(Generic[T]):
 
     @classmethod
     def builder(cls) -> "ValidationResult":
-        return ValidationResult(Messages())
+        return ValidationResult()
